AIHttp class

Constructors

AIHttp()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

delete<T>({required String from, required T onSuccess(Map<String, dynamic> response)}) Future<T>
fileUpload<T>({required String to, required T onSuccess(Map<String, dynamic>), required Map<String, String> body, required File file}) Future<T>
get<T>({required String from, bool returnRawResponse = false, T onSuccess(Map<String, dynamic>)?}) Future<T>
getStream<T>({required String from, required T onSuccess(Map<String, dynamic>)}) Stream<T>
imageEditForm<T>({required String to, required T onSuccess(Map<String, dynamic>), required File image, required File? mask, required Map<String, String> body}) Future
imageVariationForm<T>({required String to, required T onSuccess(Map<String, dynamic>), required Map<String, dynamic> body, required File image}) Future<T>
post<T>({required String to, required T onSuccess(Map<String, dynamic>), Map<String, dynamic>? body}) Future<T>
postStream<T>({required String to, required T onSuccess(Map<String, dynamic>), required Map<String, dynamic> body}) Stream<T>