AILogger class

Constructors

AILogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isEnable bool
Changes the logger enable state. true, the logger will log messages. false, the logger will not log messages. The default value is _isEnable.
no getter

Static Methods

log(String message) → void
Logs a message, if the logger is active.