Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create({String model = 'text-davinci-003', dynamic prompt, int? maxTokens = 200, double? temperature, double? topP, int? n, int? logprobs, bool? echo, String? stop, int? bestOf, String? user, String? suffix})
→ Future<AIResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited